@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 
-from CloudflareAPI.api.workers import Worker
+from CloudflareAPI.api.user import User
+from CloudflareAPI.api.worker import Worker
 from CloudflareAPI.api.storage import Storage
 from CloudflareAPI.api.account import Account
